@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Kiall Mac Innes <kiall@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -17,10 +17,12 @@ import sys
 
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_reports import guru_meditation_report as gmr
 
 from designate import hookpoints
 from designate import service
 from designate import utils
+from designate import version
 from designate.sink import service as sink_service
 
 
@@ -32,7 +34,7 @@ CONF.import_opt('threads', 'designate.sink', group='service:sink')
 def main():
     utils.read_config('designate', sys.argv)
     logging.setup(CONF, 'designate')
-    utils.setup_gmr(log_dir=cfg.CONF.log_dir)
+    gmr.TextGuruMeditation.setup_autorun(version)
 
     hookpoints.log_hook_setup()
 
