@@ -21,7 +21,7 @@ import time
 
 from oslo_config import cfg
 from oslo_log import log
-import retrying
+import tenacity
 import tooz.coordination
 
 from designate.utils import generate_uuid
@@ -32,11 +32,16 @@ from designate.i18n import _LE
 
 LOG = log.getLogger(__name__)
 
-OPTS = [
+coordination_group = cfg.OptGroup(
+    name='coordination', title="Configuration for coordination"
+)
+
+coordination_opts = [
     cfg.StrOpt('backend_url',
                help='The backend URL to use for distributed coordination. If '
                     'unset services that need coordination will function as '
-                    'a standalone service.'),
+                    'a standalone service. This is a `tooz` url - see '
+                    'https://docs.openstack.org/tooz/latest/user/compatibility.html'),  # noqa
     cfg.FloatOpt('heartbeat_interval',
                  default=1.0,
                  help='Number of seconds between heartbeats for distributed '
@@ -47,7 +52,8 @@ OPTS = [
                       'membership has changed')
 
 ]
-cfg.CONF.register_opts(OPTS, group='coordination')
+cfg.CONF.register_group(coordination_group)
+cfg.CONF.register_opts(coordination_opts, group=coordination_group)
 
 CONF = cfg.CONF
 
@@ -68,6 +74,7 @@ class CoordinationMixin(object):
 
         if CONF.coordination.backend_url is not None:
             backend_url = cfg.CONF.coordination.backend_url
+
             self._coordinator = tooz.coordination.get_coordinator(
                 backend_url, self._coordination_id)
             self._coordination_started = False
@@ -153,8 +160,10 @@ class Partitioner(object):
                         'the only worker. Please configure a coordination '
                         'backend'))
 
-    @retrying.retry(stop_max_attempt_number=5, wait_random_max=2000,
-                    retry_on_exception=_retry_if_tooz_error)
+    @tenacity.retry(stop=tenacity.stop_after_attempt(5),
+                    wait=tenacity.wait_random(max=2),
+                    retry=tenacity.retry_if_exception(_retry_if_tooz_error),
+                    reraise=True)
     def _get_members(self, group_id):
         get_members_req = self._coordinator.get_members(group_id)
         try:
