@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -64,7 +64,7 @@ class AkamaiCommands(base.Commands):
         policy.init()
         self.context.all_tenants = True
 
-        zone = self.central_api.find_domain(self.context, {"name": zone_name})
+        zone = self.central_api.find_zone(self.context, {"name": zone_name})
         akamai_zone = client.getZone(zone_name)
 
         print("Designate zone\n%s" % pformat(zone.to_dict()))
@@ -73,13 +73,13 @@ class AkamaiCommands(base.Commands):
     @base.args('pool-id', help="Pool to Sync", type=str)
     @base.args('pool-target-id', help="Pool Target to Sync", type=str)
     @base.args('--batch-size', default=20, type=int)
-    def sync_domains(self, pool_id, pool_target_id, batch_size):
+    def sync_zones(self, pool_id, pool_target_id, batch_size):
         pool, target = self._get_config(pool_id, pool_target_id)
 
         client = impl_akamai.EnhancedDNSClient(
             target.options.get("username"), target.options.get("password"))
 
-        LOG.info(_LI("Doing batches of %i") % batch_size)
+        LOG.info(_LI("Doing batches of %i"), batch_size)
 
         criterion = {"pool_id": pool_id}
         marker = None
@@ -89,7 +89,7 @@ class AkamaiCommands(base.Commands):
         self.context.all_tenants = True
 
         while (marker is not False):
-            zones = self.central_api.find_domains(
+            zones = self.central_api.find_zones(
                 self.context, criterion, limit=batch_size, marker=marker)
             update = []
 
@@ -103,6 +103,6 @@ class AkamaiCommands(base.Commands):
                 z = impl_akamai.build_zone(client, target, zone)
                 update.append(z)
 
-            LOG.info(_LI('Uploading %d Zones') % len(update))
+            LOG.info(_LI('Uploading %d Zones'), len(update))
 
             client.setZones(update)
