@@ -18,15 +18,12 @@ import os
 
 from migrate.versioning import api as versioning_api
 from oslo_config import cfg
-from oslo_log import log as logging
 from oslo_db import exception
 
 from designate.manage import base
 from designate.sqlalchemy import utils
 
 
-LOG = logging.getLogger(__name__)
-
 REPOSITORY = os.path.abspath(os.path.join(os.path.dirname(__file__), '..',
                                           'pool_manager',
                                           'cache', 'impl_sqlalchemy',
@@ -46,7 +43,7 @@ def get_manager():
     storage_db = CONF['storage:sqlalchemy'].connection
     pool_manager_cache_db = CONF['pool_manager_cache:sqlalchemy'].connection
     if storage_db == pool_manager_cache_db:
-        raise exception.DbMigrationError(
+        raise exception.DBMigrationError(
             message=(
                 "Pool Manager Cache requires its own database."
                 " Please check your config file."
