@@ -18,13 +18,20 @@ import oslo_messaging as messaging
 
 from designate.i18n import _LI
 from designate import rpc
+from designate.loggingutils import rpc_logging
 
-
+CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 MDNS_API = None
 
 
+def reset():
+    global MDNS_API
+    MDNS_API = None
+
+
+@rpc_logging(LOG, 'mdns')
 class MdnsAPI(object):
 
     """
@@ -43,7 +50,7 @@ class MdnsAPI(object):
     RPC_XFR_API_VERSION = '1.0'
 
     def __init__(self, topic=None):
-        topic = topic if topic else cfg.CONF.mdns_topic
+        topic = topic if topic else cfg.CONF['service:mdns'].mdns_topic
 
         notify_target = messaging.Target(topic=topic,
                                          namespace='notify',
@@ -71,6 +78,10 @@ class MdnsAPI(object):
 
     def notify_zone_changed(self, context, zone, host, port, timeout,
                             retry_interval, max_retries, delay):
+        if CONF['service:worker'].notify and CONF['service:worker'].enabled:
+            LOG.debug('Letting worker send NOTIFYs instead')
+            return True
+
         LOG.info(_LI("notify_zone_changed: Calling mdns for zone '%(zone)s', "
                      "serial '%(serial)s' to nameserver '%(host)s:%(port)s'"),
                  {'zone': zone.name, 'serial': zone.serial,
