@@ -21,21 +21,27 @@ from designate.notification_handler import base
 
 LOG = logging.getLogger(__name__)
 
-cfg.CONF.register_group(cfg.OptGroup(
+# TODO(trungnv): update default format for v4 and v6 in these cfg.
+neutron_group = cfg.OptGroup(
     name='handler:neutron_floatingip',
     title="Configuration for Neutron Notification Handler"
-))
+)
 
-cfg.CONF.register_opts([
-    cfg.ListOpt('notification-topics', default=['notifications']),
-    cfg.StrOpt('control-exchange', default='neutron'),
-    cfg.StrOpt('zone-id'),
-    cfg.MultiStrOpt('formatv4'),
+neutron_opts = [
+    cfg.ListOpt('notification-topics', default=['notifications'],
+                help='notification any events from neutron'),
+    cfg.StrOpt('control-exchange', default='neutron',
+               help='control-exchange for neutron notification'),
+    cfg.StrOpt('zone-id', help='Zone ID with each notification'),
+    cfg.MultiStrOpt('formatv4', help='IPv4 format'),
     cfg.MultiStrOpt('format', deprecated_for_removal=True,
-                    deprecated_reason="Replaced by 'formatv4/formatv6'",
-                    ),
-    cfg.MultiStrOpt('formatv6')
-], group='handler:neutron_floatingip')
+                deprecated_reason="Replaced by 'formatv4/formatv6'",
+                help='format which replaced by formatv4/formatv6'),
+    cfg.MultiStrOpt('formatv6', help='IPv6 format')
+]
+
+cfg.CONF.register_group(neutron_group)
+cfg.CONF.register_opts(neutron_opts, group=neutron_group)
 
 
 class NeutronFloatingHandler(base.BaseAddressHandler):
@@ -70,8 +76,8 @@ class NeutronFloatingHandler(base.BaseAddressHandler):
                     'version': 4,
                     'address': payload['floatingip']['floating_ip_address']
                 }
-                payload['floatingip']['project'] = getattr(
-                    context, 'tenant', None)
+                payload['floatingip']['project'] = context.get(
+                             "project_name", None)
                 self._create(addresses=[address],
                              extra=payload['floatingip'],
                              zone_id=zone_id,
