@@ -11,13 +11,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_log import log as logging
 
 from designate.objects.adapters.api_v2 import base
 from designate import objects
 
-LOG = logging.getLogger(__name__)
-
 
 class ZoneAPIv2Adapter(base.APIv2Adapter):
 
