@@ -11,11 +11,9 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_log import log as logging
 
 from designate.objects.adapters.yaml import base
 from designate import objects
-LOG = logging.getLogger(__name__)
 
 
 class PoolTargetMasterYAMLAdapter(base.YAMLAdapter):
