@@ -117,7 +117,8 @@ class Zone(base.DictObjectMixin, base.SoftDeleteObjectMixin,
         'status': {
             'schema': {
                 'type': 'string',
-                'enum': ['ACTIVE', 'PENDING', 'ERROR'],
+                'enum': ['ACTIVE', 'PENDING', 'ERROR',
+                        'DELETED', 'SUCCESS', 'NO_ZONE']
             },
             'read_only': True,
         },
@@ -188,6 +189,9 @@ class Zone(base.DictObjectMixin, base.SoftDeleteObjectMixin,
                 "Provided object does not match "
                 "schema", errors=errors, object=self)
 
+    def __hash__(self):
+        return hash(self.id)
+
     def validate(self):
         errors = ValidationErrorList()
 
