@@ -122,8 +122,7 @@ class Service(service.RPCService, coordination.CoordinationMixin,
         for target in self.pool.targets:
             # Fetch an instance of the Backend class, passing in the options
             # and masters
-            self.target_backends[target.id] = backend.get_backend(
-                target.type, target)
+            self.target_backends[target.id] = backend.get_backend(target)
 
         LOG.info(_LI('%d targets setup'), len(self.pool.targets))
 
