@@ -21,7 +21,7 @@ from designate.quota import base
 
 LOG = logging.getLogger(__name__)
 
-cfg.CONF.register_opts([
+quota_opts = [
     cfg.StrOpt('quota-driver', default='storage', help='Quota driver to use'),
 
     cfg.IntOpt('quota-zones', default=10,
@@ -34,7 +34,9 @@ cfg.CONF.register_opts([
                help='Number of records allowed per recordset'),
     cfg.IntOpt('quota-api-export-size', default=1000,
                help='Number of recordsets allowed in a zone export'),
-])
+]
+
+cfg.CONF.register_opts(quota_opts)
 
 
 def get_quota():
