@@ -16,7 +16,7 @@ from oslo_log import log as logging
 from oslo_utils.strutils import bool_from_string
 
 from designate import exceptions
-from designate.objects import PoolAttributeList
+from designate.objects import PoolList
 from designate.scheduler.filters import base
 
 LOG = logging.getLogger(__name__)
@@ -40,7 +40,7 @@ class AttributeFilter(base.Filter):
             "name": "example.com."
         }
 
-    The zone attributes are matched against the potential pool candiates, and
+    The zone attributes are matched against the potential pool candidates, and
     any pools that do not match **all** hints are removed.
 
     .. warning::
@@ -113,6 +113,6 @@ class AttributeFilter(base.Filter):
 
         pool_list = [pool for pool in pools if evaluate_pool(pool)]
 
-        pools = PoolAttributeList(objects=pool_list)
+        pools = PoolList(objects=pool_list)
 
         return pools
