@@ -17,7 +17,6 @@ import mock
 from mock import patch
 from oslo_config import cfg
 import oslo_messaging as messaging
-from oslo_log import log as logging
 
 from designate import exceptions
 from designate import objects
@@ -26,9 +25,6 @@ from designate.mdns import rpcapi as mdns_api
 from designate.tests.test_api.test_v2 import ApiV2TestCase
 
 
-LOG = logging.getLogger(__name__)
-
-
 class ApiV2ZonesTest(ApiV2TestCase):
     def setUp(self):
         super(ApiV2ZonesTest, self).setUp()
@@ -577,7 +573,7 @@ class ApiV2ZonesTest(ApiV2TestCase):
         # Check the headers are what we expect
         self.assertEqual(202, response.status_int)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual('""', response.body)
+        self.assertEqual(b'""', response.body)
 
     def test_invalid_xfr_request(self):
         # Create a zone
