@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -42,30 +42,30 @@ class TestCoordinationMixin(TestCase):
         service = CoordinatedService()
         service.start()
 
-        self.assertEqual(True, service._coordination_started)
+        self.assertTrue(service._coordination_started)
         self.assertIn(service.service_name.encode('utf-8'),
                       service._coordinator.get_groups().get())
         self.assertIn(service._coordination_id.encode('utf-8'),
                       service._coordinator.get_members(
-                            service.service_name).get())
+                          service.service_name).get())
         service.stop()
 
     def test_stop(self):
         service = CoordinatedService()
         service.start()
         service.stop()
-        self.assertEqual(False, service._coordination_started)
+        self.assertFalse(service._coordination_started)
 
     def test_start_no_coordination(self):
         self.config(backend_url=None, group="coordination")
         service = CoordinatedService()
         service.start()
-        self.assertEqual(None, service._coordinator)
+        self.assertIsNone(service._coordinator)
 
     def test_stop_no_coordination(self):
         self.config(backend_url=None, group="coordination")
         service = CoordinatedService()
-        self.assertEqual(None, service._coordinator)
+        self.assertIsNone(service._coordinator)
         service.start()
         service.stop()
 
