@@ -1,6 +1,6 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hp.com>
+# Author: Endre Karlson <endre.karlson@hpe.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -106,16 +106,16 @@ class TestUtils(TestCase):
 
         # Ensure there's no lock for different zones
         for zone_name in ['foo.com.', 'bar.com.', 'example.com.']:
-            self.assertEqual(True, lock.acquire(zone_name))
+            self.assertTrue(lock.acquire(zone_name))
 
         # Ensure a lock for successive calls for the same zone
-        self.assertEqual(True, lock.acquire('example2.com.'))
-        self.assertEqual(False, lock.acquire('example2.com.'))
+        self.assertTrue(lock.acquire('example2.com.'))
+        self.assertFalse(lock.acquire('example2.com.'))
 
         # Acquire, release, and reacquire
-        self.assertEqual(True, lock.acquire('example3.com.'))
+        self.assertTrue(lock.acquire('example3.com.'))
         lock.release('example3.com.')
-        self.assertEqual(True, lock.acquire('example3.com.'))
+        self.assertTrue(lock.acquire('example3.com.'))
 
     def test_limit_notify_middleware(self):
         # Set the delay
@@ -135,7 +135,7 @@ class TestUtils(TestCase):
 
         # Send the NOTIFY through the middleware
         # No problem, middleware should return None to pass it on
-        self.assertEqual(middleware.process_request(notify), None)
+        self.assertIsNone(middleware.process_request(notify))
 
     @mock.patch('designate.dnsutils.ZoneLock.acquire', return_value=False)
     def test_limit_notify_middleware_no_acquire(self, acquire):
